package br.prp.test.helpdesk.management.solicitante;

import java.util.HashSet;
import java.util.Set;

import javax.ejb.EJB;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.OverProtocol;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.persistence.ApplyScriptAfter;
import org.jboss.arquillian.persistence.ApplyScriptBefore;
import org.jboss.arquillian.persistence.ShouldMatchDataSet;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.resolver.api.DependencyResolvers;
import org.jboss.shrinkwrap.resolver.api.maven.MavenDependencyResolver;
import org.junit.Test;
import org.junit.runner.RunWith;

import br.prp.helpdesk.management.solicitante.ISolicitanteOperationsMgt;
import br.prp.helpdesk.model.Empresa;
import br.prp.helpdesk.model.Solicitante;

@RunWith(Arquillian.class)
@ApplyScriptBefore("scripts/deactivate-constraints.sql")
@ApplyScriptAfter("scripts/activate-constraints.sql")
public class SolicitanteOperationsMgtTest {

	@Deployment @OverProtocol("Servlet 3.0")
	public static EnterpriseArchive createDeployment() {
		MavenDependencyResolver resolver = DependencyResolvers.use(MavenDependencyResolver.class).loadMetadataFromPom("pom.xml");
		
		JavaArchive jar =  ShrinkWrap.create(JavaArchive.class)
				.addPackage(Solicitante.class.getPackage())
				.addPackage(ISolicitanteOperationsMgt.class.getPackage())
				.addPackage(SolicitanteOperationsMgtTest.class.getPackage())
				.addAsResource("META-INF/persistence.xml")
				.addAsManifestResource(EmptyAsset.INSTANCE, "beans.xml");
		
		return ShrinkWrap.create(EnterpriseArchive.class)
				.addAsLibraries(resolver.includeDependenciesFromPom("pom.xml").resolveAsFiles())
				.addAsModule(jar);
	}
	
	@EJB
	private ISolicitanteOperationsMgt solMgt;
	
	@Test
	@ShouldMatchDataSet("datasets/users-company.xml")
	public void cadastraSolicitanteComEmpresaNova(){
		Solicitante s = new Solicitante();
		s.setLogin("solicitante1");
		s.setEmail("paulo@gmail.com");
		s.setNome("paulo");
		s.setSenha("123456");
		s.setDepartamento("dep");
			Empresa e = new Empresa();
			e.setNome("empresa");
			Set<Solicitante> set = new HashSet<Solicitante>();
			set.add(s);
			e.setListaSolicitantes(set);
		
		s.setEmpresa(e);
		
		solMgt.cadastraSolicitante(s);
	}

}